@@ -11,17 +11,20 @@ def make_map():
     """Create, configure and return the routes Mapper"""
     map = Mapper(directory=config['pylons.paths']['controllers'],
                  always_scan=config['debug'])
-
+    map.minimization = False
+    
     # The ErrorController route (handles 404/500 error pages); it should
     # likely stay at the top, ensuring it can always be resolved
-    map.connect('error/:action/:id', controller='error')
+    map.connect('/error/{action}', controller='error')
+    map.connect('/error/{action}/{id}', controller='error')
 
     # CUSTOM ROUTES HERE
-    map.connect('', controller='check', action='index')
-    map.connect('login', controller='security', action='index')
-    map.connect('logout', controller='security', action='logout')
+    map.connect('/', controller='check', action='index')
+    map.connect('/login', controller='security', action='index')
+    map.connect('/logout', controller='security', action='logout')
 
-    map.connect(':controller/:action/:id')
-    map.connect('*url', controller='template', action='view')
+    map.connect('/{controller}')
+    map.connect('/{controller}/{action}')
+    map.connect('/{controller}/{action}/{id}')
 
     return map
