@@ -32,29 +32,31 @@ class AuthzController(BaseController):
         self.login_as = session.get('user')
         # Used as checked in user to rcs file.
         self.authz.login_as = self.login_as
-        self.reposlist = set(self.authz.get_manageable_repos_list(self.login_as))
+        self.own_reposlist = set(self.authz.get_manageable_repos_list(self.login_as))
         
         # self.reposlist_new is what in ReposRoot directory.
-        self.reposlist_real = set(_repos.Repos(cfg.repos_root).repos_list)
-        self.reposlist_real.add('/')
+        self.all_reposlist = set(_repos.Repos(cfg.repos_root).repos_list)
+        self.all_reposlist.add('/')
         
-        self.reposlist_set = self.reposlist & self.reposlist_real
-        self.reposlist_unexist = self.reposlist - self.reposlist_real
+        self.reposlist_set = self.own_reposlist & self.all_reposlist
+        self.reposlist_unexist = self.own_reposlist - self.all_reposlist
         
-        if self.authz.is_super_user(self.login_as):
-            self.reposlist_unset = self.reposlist_real - self.reposlist
+        self.is_super_user = self.authz.is_super_user(self.login_as)
+        if self.is_super_user:
+            self.reposlist_unset = self.all_reposlist - self.own_reposlist
         else:
             self.reposlist_unset = set()
             
     def __before__(self, action):
         super(AuthzController, self).__before__(action)
-        if not self.reposlist:
+        if not self.own_reposlist and not self.is_super_user:
             return redirect_to(h.url_for(controller='security', action='failed'))
 
     def index(self):
         c.revision = self.authz.version
+        c.is_super_user = self.is_super_user
         # used for functional test.
-        c.reposlist = self.reposlist
+        c.reposlist = self.own_reposlist
         
         all_avail_users = []
         all_avail_users.append([_("All users(with anon)"), '*'])
@@ -179,10 +181,12 @@ class AuthzController(BaseController):
 
         try:
             if isAddRepos:
+                assert self.is_super_user
                 repos = self.authz.add_repos(reposname)
             else:
                 repos = self.authz.get_repos(reposname)
                 if not repos:
+                    assert self.is_super_user
                     log.warning("Repos '%s' not exists. Create authz config automatically." % reposname)
                     repos = self.authz.add_repos(reposname)
                 
