@@ -1,5 +1,21 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
+#
+# Copyright (C) 2008 OpenSourceXpress Ltd. (http://www.ossxp.com)
+# Author: Jiang Xin
+# Contact: http://www.ossxp.com
+#          http://www.worldhello.net
+#          http://moinmo.in/JiangXin
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
 
 """Subversion authz config file management.
 
@@ -11,6 +27,7 @@ import rcsbackup as rcs
 import re
 import sys
 import os
+import my_fnmatch
 import StringIO
 import logging
 log = logging.getLogger(__name__)
@@ -991,7 +1008,7 @@ class Repos(object):
         path = normalize_path(path)
 
         for i in self.module_list:
-            if i.path == path:
+            if i.path.lower() == path.lower():
                 return i
         i = Module(repos=self.name , path=path)
         self.module_list.append(i)
@@ -1014,8 +1031,13 @@ class Repos(object):
         path = normalize_path(path)
 
         for i in self.module_list:
-            if i.path == path:
+            if i.path.lower() == path.lower():
                 return i
+        # OSSXP hacked subversion supports wildcard characters as module path.
+        for i in self.module_list:
+            if '*' in i.path or '?' in i.path:
+                if my_fnmatch.fnmatch(path, i.path):
+                    return i
         return None
 
     def is_blank(self):
@@ -1058,7 +1080,7 @@ class ReposList(object):
         assert isinstance(name, basestring)
 
         for repos in self.repos_list:
-            if repos.name == name:
+            if repos.name.lower() == name.lower():
                 return repos
 
         if autocreate:
@@ -1085,7 +1107,7 @@ class ReposList(object):
             raise Exception, "Repos '%s' not exist" % name
 
         repos = self.repos_list[idx]
-        assert(repos.name == name)
+        assert(repos.name.lower() == name.lower())
 
         if recursive:
             if name == '/':
@@ -1262,8 +1284,11 @@ class SvnAuthz(object):
             if stat.st_size == 0:
                 raise Exception, "Size of file (%s) is zero!" % filename
             
-            from svn import repos as _repos
-            _repos.authz_read(filename, 1)
+            try:
+                from svn import repos as _repos
+                _repos.authz_read(filename, 1)
+            except ImportError:
+                pass
     
     def __str__(self):
         buff = u""
